==> lxqt-runner_2.1.2.orig.tar.xz: lxqt-runner-2.1.2/translations/lxqt-runner_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Anwendungsstarter-Einstellungen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Positionierung:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Top margin</source>
        <translation>Oberer Rand</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="43"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="50"/>
        <source>Show on:</source>
        <translation>Anzeigen auf:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="60"/>
        <source>Show history first</source>
        <translation>Verlauf zuerst anzeigen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="67"/>
        <source>Store/show history</source>
        <translation>Verlauf speichern/anzeigen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="74"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Hinweis&lt;/b&gt;: Die Größe von Bedienelementen auf höchster Ebene ist auf 2/3 der Höhe und Breite der Arbeitsfläche beschränkt.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="77"/>
        <source>Show list with:</source>
        <translation>Liste anzeigen mit:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="84"/>
        <source> item(s)</source>
        <translation> Element(e)</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="94"/>
        <source>Clear input on launching</source>
        <translation>Eingabe beim Start verwerfen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="111"/>
        <source>Shortcut:</source>
        <translation>Tastenkürzel:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Bildschirmoberkante</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Bildschirmmitte</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation>Fokussierter Bildschirm</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation>Immer auf Bildschirm %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Anwendungsstarter </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="109"/>
        <source>Configure</source>
        <translation>Konfigurieren</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="113"/>
        <source>Clear History</source>
        <translation>Verlauf löschen</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="465"/>
        <source>Show/hide runner dialog</source>
        <translation>Zeige/verberge Runnerdialog</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Verlauf</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="846"/>
        <source>Copy calculation result to clipboard</source>
        <translation>Rechenergebnis in Zwischenablage kopieren</translation>
    </message>
</context>
</TS>

==> lxqt-runner_2.2.0.orig.tar.xz: lxqt-runner-2.2.0/translations/lxqt-runner_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Anwendungsstarter-Einstellungen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Positionierung:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Top margin</source>
        <translation>Oberer Rand</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="43"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="50"/>
        <source>Width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="57"/>
        <source>With multiple screens, if the window is shown on the focused screen,
this value is only for the smallest screen. The minimum width is 400 px.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="61"/>
        <source>%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="71"/>
        <source>Show on:</source>
        <translation>Anzeigen auf:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="108"/>
        <source>Show history first</source>
        <translation>Verlauf zuerst anzeigen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="101"/>
        <source>Store/show history</source>
        <translation>Verlauf speichern/anzeigen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="81"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Hinweis&lt;/b&gt;: Die Größe von Bedienelementen auf höchster Ebene ist auf 2/3 der Höhe und Breite der Arbeitsfläche beschränkt.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="84"/>
        <source>Show list with:</source>
        <translation>Liste anzeigen mit:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="91"/>
        <source> item(s)</source>
        <translation> Element(e)</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="115"/>
        <source>Clear input on launching</source>
        <translation>Eingabe beim Start verwerfen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="132"/>
        <source>Shortcut:</source>
        <translation>Tastenkürzel:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Bildschirmoberkante</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Bildschirmmitte</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>On Wayland, the shortcut has to be added
in the compositor settings for &apos;lxqt-runner&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="83"/>
        <source>Focused screen</source>
        <translation>Fokussierter Bildschirm</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="87"/>
        <source>Always on screen %1</source>
        <translation>Immer auf Bildschirm %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="96"/>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Anwendungsstarter </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="109"/>
        <source>Configure</source>
        <translation>Konfigurieren</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="113"/>
        <source>Clear History</source>
        <translation>Verlauf löschen</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="523"/>
        <source>Show/hide runner dialog</source>
        <translation>Zeige/verberge Runnerdialog</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Verlauf</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="846"/>
        <source>Copy calculation result to clipboard</source>
        <translation>Rechenergebnis in Zwischenablage kopieren</translation>
    </message>
</context>
</TS>
